@@ -3,7 +3,7 @@
                              -------------------
     begin                : Jul 19 2012
     copyright            : (C) 2012 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -46,7 +46,7 @@ ODTGenerator::~ODTGenerator() {}
 
 string ODTGenerator::getStyleDefinition()
 {
-    if ( styleDefinitionCache.empty() ) {
+    if ( disableStyleCache || styleDefinitionCache.empty() ) {
         ostringstream os;
 
         os  << "<office:styles>\n<style:style style:name=\"Standard\" style:family=\"paragraph\" style:class=\"text\">\n"
